@@ -1,7 +1,7 @@
 use 5.006; use strict; use warnings;
 
 package Plack::Middleware::SignedCookies;
-$Plack::Middleware::SignedCookies::VERSION = '1.200';
+$Plack::Middleware::SignedCookies::VERSION = '1.201';
 # ABSTRACT: accept only server-minted cookies
 
 use parent 'Plack::Middleware';
@@ -21,8 +21,8 @@ sub call {
 
 	local $env->{'HTTP_COOKIE'} =
 		join '; ',
-		grep { s/[ \t]*+=[ \t]*+/=/; s/[ \t]*+([-~A-Za-z0-9]{$length}+)\z//o and $1 eq _hmac $_, $secret }
-		map  { defined && /\A[ \t]*+(.*[^ \t])/ ? split /[ \t]*+;[ \t]*+/, "$1" : () }
+		grep { s/[ \t]*=[ \t]*/=/; s/[ \t]*([-~A-Za-z0-9]{$length})\z//o and $1 eq _hmac $_, $secret }
+		map  { defined && /\A[ \t]*(.*[^ \t])/s ? split /[ \t]*;[ \t]*/, "$1" : () }
 		$env->{'HTTP_COOKIE'};
 
 	delete $env->{'HTTP_COOKIE'} if '' eq $env->{'HTTP_COOKIE'};
@@ -31,11 +31,11 @@ sub call {
 		my $do_sign;
 		for ( @{ $_[0][1] } ) {
 			if ( $do_sign ) {
-				my $flags = s/(;.*)// ? $1 : '';
-				s/\A[ \t]+//, s/[ \t]+\z//, s/[ \t]*+=[ \t]*+|\z/=/; # normalise
+				my $flags = s/(;.*)//s ? $1 : '';
+				s/\A[ \t]+//, s/[ \t]+\z//, s/[ \t]*=[ \t]*|\z/=/; # normalise
 				$_ .= ' ' . _hmac( $_, $secret ) . $flags;
-				$_ .= '; secure'   if $self->secure   and $flags !~ /;[ \t]*+ secure   [ \t]*+ (?![^;])/ix;
-				$_ .= '; HTTPonly' if $self->httponly and $flags !~ /;[ \t]*+ httponly [ \t]*+ (?![^;])/ix;
+				$_ .= '; secure'   if $self->secure   and $flags !~ /;[ \t]* secure   [ \t]* (?![^;])/ix;
+				$_ .= '; HTTPonly' if $self->httponly and $flags !~ /;[ \t]* httponly [ \t]* (?![^;])/ix;
 			}
 			$do_sign = defined $do_sign ? undef : 'set-cookie' eq lc;
 		}
@@ -62,7 +62,7 @@ Plack::Middleware::SignedCookies - accept only server-minted cookies
 
 =head1 VERSION
 
-version 1.200
+version 1.201
 
 =head1 SYNOPSIS
 
